@@ -43,6 +43,9 @@ pub const GLOBAL_INSTALL_DIR: &str = ".espressif";
 /// workspace dir (see [`cargo::workspace_dir`](crate::cargo::workspace_dir)).
 pub const DEFAULT_LOCAL_INSTALL_DIR: &str = ".embuild/espressif";
 
+/// Default filename for the file that contains [`EspIdfBuildInfo`].
+pub const BUILD_INFO_FILENAME: &str = "esp-idf-build.json";
+
 /// One or more esp-idf tools.
 #[derive(Debug, Clone)]
 pub struct Tools {
@@ -150,12 +153,14 @@ impl Installer {
     }
 
     /// Add `tools` to the list of tools to install.
+    #[must_use]
     pub fn with_tools(mut self, tools: Tools) -> Self {
         self.tools.push(tools);
         self
     }
 
     /// Set the install options to `opts`.
+    #[must_use]
     pub fn opts(mut self, opts: InstallOpts) -> Self {
         self.opts = opts;
         self
@@ -163,6 +168,7 @@ impl Installer {
 
     /// Use `esp_idf_git_url` when cloning the esp-idf if [`Some`] otherwise use the
     /// default.
+    #[must_use]
     pub fn git_url(mut self, esp_idf_git_url: Option<String>) -> Self {
         self.git_url = esp_idf_git_url;
         self
@@ -175,6 +181,7 @@ impl Installer {
     /// if not inside a build script the relative dir is unspecified.
     ///
     /// When `local_install_dir` is [`Some`] implies [`InstallOpts::NO_GLOBAL_INSTALL`].
+    #[must_use]
     pub fn local_install_dir(mut self, local_install_dir: Option<PathBuf>) -> Self {
         self.local_install_dir = local_install_dir;
         self
@@ -318,9 +325,7 @@ impl Installer {
             let tools_json = tool
                 .index
                 .as_ref()
-                .map(|tools_json| {
-                    std::array::IntoIter::new([OsStr::new("--tools-json"), tools_json.as_os_str()])
-                })
+                .map(|tools_json| [OsStr::new("--tools-json"), tools_json.as_os_str()].into_iter())
                 .into_iter()
                 .flatten();
 
@@ -429,8 +434,6 @@ fn local_install_dir(dir: Option<&Path>) -> Option<PathBuf> {
 /// Info about the esp-idf build.
 #[derive(Clone, Debug, serde::Deserialize, serde::Serialize)]
 pub struct EspIdfBuildInfo {
-    /// The install dir where all tools for the compilation of the esp-idf are installed.
-    pub install_dir: PathBuf,
     /// The directory of the local cloned esp-idf repository that was used for the build.
     pub esp_idf_dir: PathBuf,
     /// The exported PATH environment variable containing all tools.
